#!/usr/bin/env python
# coding: utf-8

__package_name__ = "myrich"
from .version import __version__
from .__main__ import main

__all__ = ["main", "__package_name__", "__version__"]
